intelmq.bots.collectors.api package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.api package

## Submodules

## intelmq.bots.collectors.api.collector_api module

API Collector bot

class intelmq.bots.collectors.api.collector_api.APICollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect data by exposing a HTTP API interface

  init()
  name: str = 'API'
  port: int = 5000
  process()
  provider: str = 'APICollector'
  request_handler(data)
  shutdown()
  socket_path = '/tmp/imq_api_default_socket'
  use_socket = False

class intelmq.bots.collectors.api.collector_api.Application(request_handler, *args, **kwargs)

  Bases: `tornado.web.Application`

intelmq.bots.collectors.api.collector_api.BOT

  alias of `intelmq.bots.collectors.api.collector_api.APICollectorBot`

class intelmq.bots.collectors.api.collector_api.MainHandler(application: tornado.web.Application, request: tornado.httputil.HTTPServerRequest, **kwargs: Any)

  Bases: `tornado.web.RequestHandler`

  post()

## Module contents